@@ -1,5 +1,5 @@
 regression <-
-function(regressor=NULL, data=NULL, pre=function(x, y=NULL) { list(features=x) }, combine=min, stack=F, expand=identity) {
+function(regressor=NULL, data=NULL, pre=function(x, y=NULL) { list(features=x) }, combine=NULL, expand=identity) {
     if(is.null(regressor)) {
         stop("No regressor given!")
     }
@@ -7,6 +7,7 @@ function(regressor=NULL, data=NULL, pre=function(x, y=NULL) { list(features=x) }
         stop("Need data with train/test split!")
     }
 
+    totalBests = breakBestTies(data)
     predictions = parallelMap(function(i) {
         trf = pre(subset(data$train[[i]], T, data$features))
         tsf = pre(subset(data$test[[i]], T, data$features), trf$meta)
@@ -15,19 +16,19 @@ function(regressor=NULL, data=NULL, pre=function(x, y=NULL) { list(features=x) }
         performancePredictions = matrix(nrow=nrow(tsf$features), ncol=length(data$performance))
         for (j in 1:length(data$performance)) {
             model = regressor(data$train[[i]][[data$performance[j]]]~., data=trf$features)
-            if(stack) {
+            if(!is.null(combine)) {
                 trainpredictions[,j] = predict(model, trf$features)
             }
             performancePredictions[,j] = predict(model, tsf$features)
         }
 
-        if(stack) {
-            combinedmodel = combine(data$train[[i]]$best~., data=data.frame(expand(trainpredictions)))
+        if(!is.null(combine)) {
+            trainBests = breakBestTies(data, i)
+            combinedmodel = combine(trainBests~., data=data.frame(expand(trainpredictions)))
             preds = as.character(predict(combinedmodel, data.frame(expand(performancePredictions))))
             combinedpredictions = lapply(preds, function(l) { setNames(data.frame(table(l)), predNames) })
         } else {
-            # this is hacky and should be replaced...
-            if(deparse(combine) == ".Primitive(\"min\")") {
+            if(data$minimize) {
                 decreasing = F
             } else {
                 decreasing = T
@@ -43,12 +44,12 @@ function(regressor=NULL, data=NULL, pre=function(x, y=NULL) { list(features=x) }
         data$data[[data$performance[i]]]
         return(regressor(data$data[[data$performance[i]]]~., data=fs$features))
     })
-    if(stack) {
+    if(!is.null(combine)) {
         trainpredictions = matrix(nrow=nrow(fs$features), ncol=length(data$performance))
         for (i in 1:length(data$performance)) {
             trainpredictions[,i] = predict(models[[i]], fs$features)
         }
-        combinedmodel = combine(data$data$best~., data=data.frame(expand(trainpredictions)))
+        combinedmodel = combine(totalBests~., data=data.frame(expand(trainpredictions)))
     }
 
     return(list(predictions=predictions, models=models, predictor=function(x) {
@@ -58,11 +59,11 @@ function(regressor=NULL, data=NULL, pre=function(x, y=NULL) { list(features=x) }
             performancePredictions[,i] = predict(models[[i]], tsf$features)
         }
 
-        if(stack) {
+        if(!is.null(combine)) {
             preds = as.character(predict(combinedmodel, data.frame(expand(performancePredictions))))
             combinedpredictions = lapply(preds, function(l) { setNames(data.frame(table(l)), predNames) })
         } else {
-            if(deparse(combine) == ".Primitive(\"min\")") {
+            if(data$minimize) {
                 decreasing = F
             } else {
                 decreasing = T
