@@ -7,15 +7,15 @@ predict.othertestclassifier = function(object, y) { return(rep.int("a", nrow(y))
 setMethod("predict", signature(object="othertestclassifier"), predict.othertestclassifier, where=globalenv())
 
 test_that("classify classifies", {
-    fold = data.frame(a=rep.int(0, 10), best=rep.int("b", 10))
-    d = list(data=rbind(fold, fold), train=list(fold), test=list(fold), features=c("a"))
+    fold = data.frame(a=rep.int(0, 10), b=rep.int(1, 10), best=rep.int("b", 10))
+    d = list(data=rbind(fold, fold), train=list(fold), test=list(fold), features=c("a"), minimize=T, performance=c("b"))
     res = classify(classifier=testclassifier, d)
     expect_true(all(sapply(1:length(res$predictions), function(i) { sapply(res$predictions[[i]], function(x) { x == data.frame(algorithm="b", score=1) }) })))
 })
 
 test_that("classify returns predictor", {
-    fold = data.frame(a=rep.int(0, 10), best=rep.int("b", 10))
-    d = list(data=rbind(fold, fold), train=list(fold), test=list(fold), features=c("a"))
+    fold = data.frame(a=rep.int(0, 10), b=rep.int(1, 10), best=rep.int("b", 10))
+    d = list(data=rbind(fold, fold), train=list(fold), test=list(fold), features=c("a"), minimize=T, performance=c("b"))
     res = classify(classifier=testclassifier, d)
     expect_true(all(sapply(res$predictor(fold), function(x) { x == data.frame(algorithm="b", score=1) })))
 })
@@ -29,24 +29,24 @@ test_that("classify raises error without train/test split", {
 })
 
 test_that("classify takes list of classifiers", {
-    fold = data.frame(a=rep.int(0, 10), best=rep.int("b", 10))
-    d = list(data=rbind(fold, fold), train=list(fold), test=list(fold), features=c("a"))
+    fold = data.frame(a=rep.int(0, 10), b=rep.int(1, 10), best=rep.int("b", 10))
+    d = list(data=rbind(fold, fold), train=list(fold), test=list(fold), features=c("a"), minimize=T, performance=c("b"))
     res = classify(classifier=list(testclassifier, testclassifier, testclassifier), d)
     expect_true(all(sapply(1:length(res$predictions), function(i) { sapply(res$predictions[[i]], function(x) { x == data.frame(algorithm="b", score=3) }) })))
     expect_true(all(sapply(res$predictor(fold), function(x) { x == data.frame(algorithm="b", score=3) })))
 })
 
 test_that("classify takes list of classifiers and combination function", {
-    fold = data.frame(a=rep.int(0, 10), best=rep.int("b", 10))
-    d = list(data=rbind(fold, fold), train=list(fold), test=list(fold), features=c("a"))
+    fold = data.frame(a=rep.int(0, 10), b=rep.int(1, 10), best=rep.int("b", 10))
+    d = list(data=rbind(fold, fold), train=list(fold), test=list(fold), features=c("a"), minimize=T, performance=c("b"))
     res = classify(classifier=list(testclassifier, testclassifier, testclassifier, .combine=othertestclassifier), d)
     expect_true(all(sapply(1:length(res$predictions), function(i) { sapply(res$predictions[[i]], function(x) { x == data.frame(algorithm="a", score=1) }) })))
     expect_true(all(sapply(res$predictor(fold), function(x) { x == data.frame(algorithm="a", score=1) })))
 })
 
 test_that("classify ensemble does majority voting by default", {
-    fold = data.frame(a=rep.int(0, 10), best=rep.int("b", 10))
-    d = list(data=rbind(fold, fold), train=list(fold), test=list(fold), features=c("a"))
+    fold = data.frame(a=rep.int(0, 10), b=rep.int(1, 10), best=rep.int("b", 10))
+    d = list(data=rbind(fold, fold), train=list(fold), test=list(fold), features=c("a"), minimize=T, performance=c("b"))
     res = classify(classifier=list(testclassifier, othertestclassifier, othertestclassifier), d)
     expect_true(all(sapply(1:length(res$predictions), function(i) { sapply(res$predictions[[i]], function(x) { x == data.frame(algorithm=c("a", "b"), score=c(2, 1)) }) })))
     expect_true(all(sapply(res$predictor(fold), function(x) { x == data.frame(algorithm=c("a", "b"), score=c(2, 1)) })))
